summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorBertrik Sikken <bertrik@sikken.nl>2010-11-05 09:51:19 +0000
committerBertrik Sikken <bertrik@sikken.nl>2010-11-05 09:51:19 +0000
commitfffbdcc9960b6a2d8bf50f3c67674278780ad00f (patch)
tree30f0bc187963d48d9c72a31be059eb48f5d6e7cb
parent41910a04b7a28b6613ff0ff3803c736b3c899862 (diff)
downloadrockbox-fffbdcc9960b6a2d8bf50f3c67674278780ad00f.tar.gz
rockbox-fffbdcc9960b6a2d8bf50f3c67674278780ad00f.zip
Correct spelling of 'seperate' in the skin parsing code - FS#11724 by Alexander Levin
git-svn-id: svn://svn.rockbox.org/rockbox/trunk@28485 a1c6a512-1295-4272-9138-f99709370657
-rw-r--r--lib/skin_parser/skin_debug.c6
-rw-r--r--lib/skin_parser/skin_parser.c34
-rw-r--r--lib/skin_parser/skin_parser.h2
-rw-r--r--lib/skin_parser/skin_scan.c2
-rw-r--r--lib/skin_parser/symbols.h4
5 files changed, 24 insertions, 24 deletions
diff --git a/lib/skin_parser/skin_debug.c b/lib/skin_parser/skin_debug.c
index 3a5a5a7441..a09cd673c7 100644
--- a/lib/skin_parser/skin_debug.c
+++ b/lib/skin_parser/skin_debug.c
@@ -85,14 +85,14 @@ void skin_error(enum skin_errorcode error, const char* cursor)
case DECIMAL_EXPECTED:
error_message = "Expected decimal";
break;
- case SEPERATOR_EXPECTED:
- error_message = "Expected argument seperator";
+ case SEPARATOR_EXPECTED:
+ error_message = "Expected argument separator";
break;
case CLOSE_EXPECTED:
error_message = "Expected list close";
break;
case MULTILINE_EXPECTED:
- error_message = "Expected subline seperator";
+ error_message = "Expected subline separator";
break;
};
diff --git a/lib/skin_parser/skin_parser.h b/lib/skin_parser/skin_parser.h
index 7cef0107a3..6f1af25a05 100644
--- a/lib/skin_parser/skin_parser.h
+++ b/lib/skin_parser/skin_parser.h
@@ -58,7 +58,7 @@ enum skin_errorcode
INSUFFICIENT_ARGS,
INT_EXPECTED,
DECIMAL_EXPECTED,
- SEPERATOR_EXPECTED,
+ SEPARATOR_EXPECTED,
CLOSE_EXPECTED,
MULTILINE_EXPECTED
};
diff --git a/lib/skin_parser/skin_scan.c b/lib/skin_parser/skin_scan.c
index de9c423f04..50d58bc250 100644
--- a/lib/skin_parser/skin_scan.c
+++ b/lib/skin_parser/skin_scan.c
@@ -101,7 +101,7 @@ char* scan_string(const char** document)
char* buffer = NULL;
int i;
- while(*cursor != ARGLISTSEPERATESYM && *cursor != ARGLISTCLOSESYM &&
+ while(*cursor != ARGLISTSEPARATESYM && *cursor != ARGLISTCLOSESYM &&
*cursor != '\0')
{
if(*cursor == COMMENTSYM)
diff --git a/lib/skin_parser/symbols.h b/lib/skin_parser/symbols.h
index b4f31289ef..e18a770d3b 100644
--- a/lib/skin_parser/symbols.h
+++ b/lib/skin_parser/symbols.h
@@ -36,8 +36,8 @@ extern "C"
#define MULTILINESYM ';'
#define ARGLISTOPENSYM '('
#define ARGLISTCLOSESYM ')'
-#define ARGLISTSEPERATESYM ','
-#define ENUMLISTSEPERATESYM '|'
+#define ARGLISTSEPARATESYM ','
+#define ENUMLISTSEPARATESYM '|'
#define ENUMLISTOPENSYM '<'
#define ENUMLISTCLOSESYM '>'
#define DEFAULTSYM '-'
diff --git a/lib/skin_parser/skin_parser.c b/lib/skin_parser/skin_parser.c
index 689a315bfa..5a5d746c8e 100644
--- a/lib/skin_parser/skin_parser.c
+++ b/lib/skin_parser/skin_parser.c
@@ -261,7 +261,7 @@ static struct skin_element* skin_parse_line(const char**document)
/*
* If conditional is set to true, then this will break upon encountering
- * SEPERATESYM. This should only be used when parsing a line inside a
+ * SEPARATESYM. This should only be used when parsing a line inside a
* conditional, otherwise just use the wrapper function skin_parse_line()
*/
static struct skin_element* skin_parse_line_optional(const char** document,
@@ -280,9 +280,9 @@ static struct skin_element* skin_parse_line_optional(const char** document,
retval->type = LINE;
retval->line = skin_line;
if(*cursor != '\0' && *cursor != '\n' && *cursor != MULTILINESYM
- && !(conditional && (*cursor == ARGLISTSEPERATESYM
+ && !(conditional && (*cursor == ARGLISTSEPARATESYM
|| *cursor == ARGLISTCLOSESYM
- || *cursor == ENUMLISTSEPERATESYM
+ || *cursor == ENUMLISTSEPARATESYM
|| *cursor == ENUMLISTCLOSESYM)))
{
retval->children_count = 1;
@@ -313,9 +313,9 @@ static struct skin_element* skin_parse_line_optional(const char** document,
#endif
while(*cursor != '\n' && *cursor != '\0' && *cursor != MULTILINESYM
- && !((*cursor == ARGLISTSEPERATESYM
+ && !((*cursor == ARGLISTSEPARATESYM
|| *cursor == ARGLISTCLOSESYM
- || *cursor == ENUMLISTSEPERATESYM
+ || *cursor == ENUMLISTSEPARATESYM
|| *cursor == ENUMLISTCLOSESYM)
&& conditional)
&& !(check_viewport(cursor) && cursor != *document))
@@ -390,9 +390,9 @@ static struct skin_element* skin_parse_sublines_optional(const char** document,
/* First we count the sublines */
while(*cursor != '\0' && *cursor != '\n'
- && !((*cursor == ARGLISTSEPERATESYM
+ && !((*cursor == ARGLISTSEPARATESYM
|| *cursor == ARGLISTCLOSESYM
- || *cursor == ENUMLISTSEPERATESYM
+ || *cursor == ENUMLISTSEPARATESYM
|| *cursor == ENUMLISTCLOSESYM)
&& conditional)
&& !(check_viewport(cursor) && cursor != *document))
@@ -565,7 +565,7 @@ static int skin_parse_tag(struct skin_element* element, const char** document)
{
skip_arglist(&cursor);
}
- else if(*cursor == ARGLISTSEPERATESYM)
+ else if(*cursor == ARGLISTSEPARATESYM)
{
num_args++;
cursor++;
@@ -753,9 +753,9 @@ static int skin_parse_tag(struct skin_element* element, const char** document)
skip_whitespace(&cursor);
- if(*cursor != ARGLISTSEPERATESYM && i < num_args - 1)
+ if(*cursor != ARGLISTSEPARATESYM && i < num_args - 1)
{
- skin_error(SEPERATOR_EXPECTED, cursor);
+ skin_error(SEPARATOR_EXPECTED, cursor);
return 0;
}
else if(*cursor != ARGLISTCLOSESYM && i == num_args - 1)
@@ -801,7 +801,7 @@ static int skin_parse_tag(struct skin_element* element, const char** document)
/*
* If the conditional flag is set true, then parsing text will stop at an
* ARGLISTSEPERATESYM. Only set that flag when parsing within a conditional
*/
static int skin_parse_text(struct skin_element* element, const char** document,
int conditional)
@@ -814,9 +814,9 @@ static int skin_parse_text(struct skin_element* element, const char** document,
/* First figure out how much text we're copying */
while(*cursor != '\0' && *cursor != '\n' && *cursor != MULTILINESYM
&& *cursor != COMMENTSYM
- && !((*cursor == ARGLISTSEPERATESYM
+ && !((*cursor == ARGLISTSEPARATESYM
|| *cursor == ARGLISTCLOSESYM
- || *cursor == ENUMLISTSEPERATESYM
+ || *cursor == ENUMLISTSEPARATESYM
|| *cursor == ENUMLISTCLOSESYM)
&& conditional))
{
@@ -932,7 +932,7 @@ static int skin_parse_conditional(struct skin_element* element, const char** doc
break;
cursor++;
}
- else if(*cursor == ENUMLISTSEPERATESYM)
+ else if(*cursor == ENUMLISTSEPARATESYM)
{
children++;
cursor++;
@@ -984,9 +984,9 @@ static int skin_parse_conditional(struct skin_element* element, const char** doc
cursor = conditional_end;
#endif
- if(i < children - 1 && *cursor != ENUMLISTSEPERATESYM)
+ if(i < children - 1 && *cursor != ENUMLISTSEPARATESYM)
{
- skin_error(SEPERATOR_EXPECTED, cursor);
+ skin_error(SEPARATOR_EXPECTED, cursor);
return 0;
}
else if(i == children - 1 && *cursor != ENUMLISTCLOSESYM)
@@ -1048,7 +1048,7 @@ static struct skin_element* skin_parse_code_as_arg(const char** document)
/* Checking for sublines */
while(*cursor != '\n' && *cursor != '\0'
- && *cursor != ENUMLISTSEPERATESYM && *cursor != ARGLISTSEPERATESYM
+ && *cursor != ENUMLISTSEPARATESYM && *cursor != ARGLISTSEPARATESYM
&& *cursor != ENUMLISTCLOSESYM && *cursor != ARGLISTCLOSESYM)
{
if(*cursor == MULTILINESYM)
@@ -801,7 +801,7 @@ static int skin_parse_tag(struct skin_element* element, const char** document)
/*
* If the conditional flag is set true, then parsing text will stop at an
- * ARGLISTSEPERATESYM. Only set that flag when parsing within a conditional
+ * ARGLISTSEPARATESYM. Only set that flag when parsing within a conditional
*/
static int skin_parse_text(struct skin_element* element, const char** document,